@@ -1,6 +1,8 @@
 import os
 import sys
 import inspect
+import signal
+import subprocess
 
 from django.core.management.base import BaseCommand
 
@@ -97,22 +99,28 @@ class Command(BaseCommand):
         url_aliases = options.setdefault('url_aliases') or []
 
         try:
-            if settings.STATIC_URL and settings.STATIC_URL.startswith('/'):
-                if settings.STATIC_ROOT:
-                    # We need a fiddle here as depending on the Python
-                    # version used, the list of URL aliases we are
-                    # passed could be either list of tuples or list of
-                    # lists. We need to ensure we use the same type so
-                    # that sorting of items in the lists works later.
+            middleware = getattr(settings, 'MIDDLEWARE', None)
 
-                    if not url_aliases:
-                        url_aliases.insert(0, (
-                                settings.STATIC_URL.rstrip('/') or '/',
-                                settings.STATIC_ROOT))
-                    else:
-                        url_aliases.insert(0, type(url_aliases[0])((
-                                settings.STATIC_URL.rstrip('/') or '/',
-                                settings.STATIC_ROOT)))
+            if middleware is None:
+                middleware = getattr(settings, 'MIDDLEWARE_CLASSES', [])
+
+            if 'whitenoise.middleware.WhiteNoiseMiddleware' not in middleware: 
+                if settings.STATIC_URL and settings.STATIC_URL.startswith('/'):
+                    if settings.STATIC_ROOT:
+                        # We need a fiddle here as depending on the Python
+                        # version used, the list of URL aliases we are
+                        # passed could be either list of tuples or list of
+                        # lists. We need to ensure we use the same type so
+                        # that sorting of items in the lists works later.
+
+                        if not url_aliases:
+                            url_aliases.insert(0, (
+                                    settings.STATIC_URL.rstrip('/') or '/',
+                                    settings.STATIC_ROOT))
+                        else:
+                            url_aliases.insert(0, type(url_aliases[0])((
+                                    settings.STATIC_URL.rstrip('/') or '/',
+                                    settings.STATIC_ROOT)))
 
         except AttributeError:
             pass
@@ -127,4 +135,28 @@ class Command(BaseCommand):
 
         executable = os.path.join(options['server_root'], 'apachectl')
         name = executable.ljust(len(options['process_name']))
-        os.execl(executable, name, 'start', '-DFOREGROUND')
+
+        if options['isatty'] and sys.stdout.isatty():
+            process = None
+
+            def handler(signum, frame):
+                if process is None:
+                    sys.exit(1)
+
+                else:
+                    if signum not in [signal.SIGWINCH]:
+                        os.kill(process.pid, signum)
+
+            signal.signal(signal.SIGINT, handler)
+            signal.signal(signal.SIGTERM, handler)
+            signal.signal(signal.SIGHUP, handler)
+            signal.signal(signal.SIGUSR1, handler)
+            signal.signal(signal.SIGWINCH, handler)
+
+            process = subprocess.Popen([executable, 'start', '-DFOREGROUND'],
+                    preexec_fn=os.setpgrp)
+
+            process.wait()
+
+        else:
+            os.execl(executable, name, 'start', '-DFOREGROUND')
